/*
 * Copyright 2008-2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.core.web.catalog;

import java.io.IOException;

import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;

import org.broadleafcommerce.core.catalog.service.dynamic.SkuPricingConsiderationContext;

/**
 * 
 * @author jfischer
 *
 */
public abstract class AbstractDynamicSkuPricingFilter implements DynamicSkuPricingFilter {

    public void destroy() {
        //do nothing
    }

    public void doFilter(ServletRequest request, ServletResponse response, FilterChain filterChain) throws IOException, ServletException {
        SkuPricingConsiderationContext.setSkuPricingConsiderationContext(getPricingConsiderations(request));
        SkuPricingConsiderationContext.setSkuPricingService(getDynamicSkuPricingService(request));
        try {
            filterChain.doFilter(request, response);
        } finally {
            SkuPricingConsiderationContext.setSkuPricingConsiderationContext(null);
            SkuPricingConsiderationContext.setSkuPricingService(null);
        }
        
    }

    public void init(FilterConfig arg0) throws ServletException {
        //do nothing
    }
    
    

}
